wsipipe.utils package
=====================

.. automodule:: wsipipe.utils
   :members:
   :undoc-members:
   :show-inheritance:

convert module
----------------------------

.. automodule:: wsipipe.utils.convert
   :members:
   :undoc-members:
   :show-inheritance:

filters module
----------------------------

.. automodule:: wsipipe.utils.filters
   :members:
   :undoc-members:
   :show-inheritance:

geometry module
-----------------------------

.. automodule:: wsipipe.utils.geometry
   :members:
   :undoc-members:
   :show-inheritance:

